==> haskell-conduit-parse-0.2.1.1-279-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-parse
version:              0.2.1.1
visibility:           public
id:                   conduit-parse-0.2.1.1-9MidOXVTinWCq8yyl0NeYy
key:                  conduit-parse-0.2.1.1-9MidOXVTinWCq8yyl0NeYy
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  53e0ce35e0516969f2cb433f295576cf
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-parse
hs-libraries:         HSconduit-parse-0.2.1.1-9MidOXVTinWCq8yyl0NeYy
depends:
    base-4.17.2.1 conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    dlist-1.0-E99MqJW5mmB4kr4PCgIESI mtl-2.2.2
    parsers-0.12.12-LBDYop5QYiCC1l4dJj3TCF
    safe-0.3.21-FBimV6u2RMNDKpiH5qP0vN
    safe-exceptions-0.1.7.4-JJtencRNvfPAVPHD6bpNCc text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-parse-0.2.1.1-299-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-parse
version:              0.2.1.1
visibility:           public
id:                   conduit-parse-0.2.1.1-yi6giLqzQ0LD4pCsjh3ej
key:                  conduit-parse-0.2.1.1-yi6giLqzQ0LD4pCsjh3ej
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  a8408a078c3b8712a52a3404a152f42b
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-parse
hs-libraries:         HSconduit-parse-0.2.1.1-yi6giLqzQ0LD4pCsjh3ej
depends:
    base-4.17.2.1 conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    dlist-1.0-DlYyWPxbaG7vpSilKIFCh mtl-2.2.2
    parsers-0.12.12-AruA0KJE2LQHQP2zlD1Eci
    safe-0.3.21-JMKA2bKqr97GM6r3OADsOi
    safe-exceptions-0.1.7.4-E2jhex6cl0w6t2rEagsyOt text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
